.. This is part of the Photini documentation.
   Copyright (C)  2012-15  Jim Easterbrook.
   See the file DOC_LICENSE.txt for copying condidions.

Introduction
============

.. include:: ../../../README.rst
   :start-line: 2
   :end-before: .. image:

.. image:: ../images/screenshot_11.png

.. include:: ../../../README.rst
   :start-after: Text editing screenshot
   :end-before: .. image

.. image:: ../images/screenshot_66.png

.. include:: ../../../README.rst
   :start-after: Geotagging screenshot
   :end-before: Documentation

.. include:: ../../../README.rst
   :start-after: _readme-getting_help:
